==> axiom-1.2.22-src.zip: axiom-1.2.22/testing/saaj-testsuite/src/main/java/org/apache/axiom/ts/saaj/SAAJTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.saaj;

import javax.xml.soap.MessageFactory;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPFactory;

import org.apache.axiom.testutils.suite.MatrixTestCase;
import org.apache.axiom.ts.soap.SOAPSpec;

public abstract class SAAJTestCase extends MatrixTestCase {
    protected final SAAJImplementation saajImplementation;
    protected final SOAPSpec spec;

    public SAAJTestCase(SAAJImplementation saajImplementation, SOAPSpec spec) {
        this.saajImplementation = saajImplementation;
        this.spec = spec;
        addTestParameter("spec", spec.getName());
    }
    
    protected final MessageFactory newMessageFactory() throws SOAPException {
        return spec.getAdapter(FactorySelector.class).newMessageFactory(saajImplementation);
    }
    
    protected final SOAPFactory newSOAPFactory() throws SOAPException {
        return spec.getAdapter(FactorySelector.class).newSOAPFactory(saajImplementation);
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/saaj-testsuite/src/main/java/org/apache/axiom/ts/saaj/SAAJTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.saaj;

import jakarta.xml.soap.MessageFactory;
import jakarta.xml.soap.SOAPException;
import jakarta.xml.soap.SOAPFactory;

import org.apache.axiom.testutils.suite.MatrixTestCase;
import org.apache.axiom.ts.soap.SOAPSpec;

public abstract class SAAJTestCase extends MatrixTestCase {
    protected final SAAJImplementation saajImplementation;
    protected final SOAPSpec spec;

    public SAAJTestCase(SAAJImplementation saajImplementation, SOAPSpec spec) {
        this.saajImplementation = saajImplementation;
        this.spec = spec;
        addTestParameter("spec", spec.getName());
    }

    protected final MessageFactory newMessageFactory() throws SOAPException {
        return spec.getAdapter(FactorySelector.class).newMessageFactory(saajImplementation);
    }

    protected final SOAPFactory newSOAPFactory() throws SOAPException {
        return spec.getAdapter(FactorySelector.class).newSOAPFactory(saajImplementation);
    }
}
